present

# XMLRésuméLibrary: User Guide

prefecture | Element Reference | project

## Name

present — Indicates the current time

## Synopsis

### Content Model

    EMPTY

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `present` element denotes the current time, as opposed to a fixed time in the past or future. It is most commonly used in date ranges, to express things like “From May 1995 to present”.

`present` is a null element, that is, it has no content or attributes. It is always written as `<present/>`.

### Parents

`present` may be contained in these elements: `from`, `to`

## See Also

`date`.

## Examples

    <period>
      <from><date>
        <month>May</month>
        <year>1995</year>
      </from>
      <to>
        <present/>
      </to>
    </period>

prefecture | Element Reference | project